@@ -1,4 +1,4 @@
-from typing import TypeVar, List, Union, Mapping
+from typing import TypeVar, List, Union, Mapping, Callable
 
 ConfigFile = str
 ConfigName = str
@@ -10,9 +10,10 @@ ConfigDict = Mapping[ConfigKey, ConfigValue]
 ProfileKey = str
 ProfileName = str
 
-PROFILE_WILDCARD = "*"
+WILDCARD = "*"
 PROFILE_NAME_KEY = "profile"
 CONFIG_NAME_KEY = ["group", "name"]
+ConfigNameGetter = Callable[["ConfigSnippet"], ConfigName]
 
 KT = TypeVar("KT")
 VT = TypeVar("VT")
